@@ -147,7 +147,7 @@
 #include <iostream>
 #include <vector>
 
-
+namespace contourpy {
 namespace mpl2014 {
 
 // Edge of a quad including diagonal edges of masked quads if _corner_mask true.
@@ -485,11 +485,11 @@ private:
         const double& level);
 
     // Debug function that writes the cache status to stdout.
-    void write_cache(bool grid_only = false) const;
+    //void write_cache(bool grid_only = false) const;
 
     // Debug function that writes that cache status for a single quad to
     // stdout.
-    void write_cache_quad(index_t quad, bool grid_only) const;
+    //void write_cache_quad(index_t quad, bool grid_only) const;
 
 
 
@@ -513,5 +513,6 @@ private:
 };
 
 } // namespace mpl2014
+} // namespace contourpy
 
 #endif // #define CONTOURPY_MPL_2014_H
