@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import numpy as np
 import pytest
 
@@ -9,13 +11,22 @@ from contourpy.util.data import random
 @pytest.mark.text
 @pytest.mark.parametrize("show_text", [False, True])
 @pytest.mark.parametrize("fill_type", FillType.__members__.values())
-def test_renderer_filled(show_text, fill_type):
-    from contourpy.util.mpl_renderer import MplRenderer
+@pytest.mark.parametrize("renderer_type", ["mpl", "bokeh"])
+def test_renderer_filled(show_text: bool, fill_type: FillType, renderer_type: str) -> None:
+    if renderer_type == "bokeh":
+        try:
+            from contourpy.util.bokeh_renderer import BokehRenderer as Renderer
+        except ImportError:
+            pytest.skip("Optional bokeh dependencies not installed")
+    elif renderer_type == "mpl":
+        from contourpy.util.mpl_renderer import MplRenderer as Renderer  # type: ignore[no-redef]
+    else:
+        raise ValueError(f"Unrecognised renderer type {renderer_type}")
 
     from .image_comparison import compare_images
 
     x, y, z = random((3, 4))
-    renderer = MplRenderer(ncols=2, figsize=(8, 3), show_frame=False)
+    renderer = Renderer(ncols=2, figsize=(8, 3), show_frame=False)
     for ax, quad_as_tri in enumerate((False, True)):
         cont_gen = contour_generator(x, y, z, fill_type=fill_type)
 
@@ -38,20 +49,32 @@ def test_renderer_filled(show_text, fill_type):
 
     image_buffer = renderer.save_to_buffer()
     suffix = "" if show_text else "_no_text"
-    compare_images(image_buffer, f"renderer_filled_mpl{suffix}.png", f"{fill_type}")
+    compare_images(
+        image_buffer, f"renderer_filled_{renderer_type}{suffix}.png", f"{fill_type}",
+        mean_threshold=0.03 if renderer_type == "bokeh" else None,
+    )
 
 
 @pytest.mark.image
 @pytest.mark.text
 @pytest.mark.parametrize("show_text", [False, True])
 @pytest.mark.parametrize("line_type", LineType.__members__.values())
-def test_renderer_lines(show_text, line_type):
-    from contourpy.util.mpl_renderer import MplRenderer
+@pytest.mark.parametrize("renderer_type", ["mpl", "bokeh"])
+def test_renderer_lines(show_text: bool, line_type: LineType, renderer_type: str) -> None:
+    if renderer_type == "bokeh":
+        try:
+            from contourpy.util.bokeh_renderer import BokehRenderer as Renderer
+        except ImportError:
+            pytest.skip("Optional bokeh dependencies not installed")
+    elif renderer_type == "mpl":
+        from contourpy.util.mpl_renderer import MplRenderer as Renderer  # type: ignore[no-redef]
+    else:
+        raise ValueError(f"Unrecognised renderer type {renderer_type}")
 
     from .image_comparison import compare_images
 
     x, y, z = random((3, 4))
-    renderer = MplRenderer(ncols=2, figsize=(8, 3), show_frame=show_text)
+    renderer = Renderer(ncols=2, figsize=(8, 3), show_frame=show_text)
     for ax, quad_as_tri in enumerate((False, True)):
         cont_gen = contour_generator(x, y, z, line_type=line_type)
 
@@ -76,4 +99,4 @@ def test_renderer_lines(show_text, line_type):
 
     image_buffer = renderer.save_to_buffer()
     suffix = "" if show_text else "_no_text"
-    compare_images(image_buffer, f"renderer_lines_mpl{suffix}.png", f"{line_type}")
+    compare_images(image_buffer, f"renderer_lines_{renderer_type}{suffix}.png", f"{line_type}")
